/****************************************************************************/

#include "winlib.h"

/*****************************************************************************
 * Name         - CWindowClass Constructor
 * Purpose      - The constructor of CWindowClass initializes all of the
 *                members of the class to the most sensibile default values
 *                I could think of.
 * Arguments    - WndProc: Pointer to the window procedure to use for the
 *                windows of this class
 *                ClassId: Resource ID of the string that defines the class
 *                         name
 *                hInst: Instance handle of the program
 * Return Value - None
 ****************************************************************************/
CWindowClass::CWindowClass (WNDPROC wndProc , INT classId , HINSTANCE hInst)
    : className (hInst, classId)
{
 // Provide reasonable default values
 cbSize = sizeof (WNDCLASSEX);
 style = 0;
 lpfnWndProc = wndProc;
 lpszClassName = className;
 hInstance = hInst;
 hIcon = 0;
 hIconSm = 0;
 lpszMenuName = 0;
 cbClsExtra = 0;
 cbWndExtra = 0;
 hbrBackground = (HBRUSH) (COLOR_WINDOW + 1);
 hCursor = LoadCursor (0, IDC_ARROW);
}

/*****************************************************************************
 * Name         - CWindowClass Constructor
 * Purpose      - Another constructor like above but take a string constant
 *                as the class name.
 * Arguments    - See above
 * Return Value - None
 ****************************************************************************/
CWindowClass::CWindowClass (WNDPROC wndProc , CHAR *strClassName , HINSTANCE hInst)
{
 // Provide reasonable default values
 cbSize = sizeof (WNDCLASSEX);
 style = 0;
 lpfnWndProc = wndProc;
 lpszClassName = strClassName;
 hInstance = hInst;
 hIcon = 0;
 hIconSm = 0;
 lpszMenuName = 0;
 cbClsExtra = 0;
 cbWndExtra = 0;
 hbrBackground = (HBRUSH) (COLOR_WINDOW + 1);
 hCursor = LoadCursor (0, IDC_ARROW);
}

/*****************************************************************************
 * Name         - CWindowClass::setResIcons
 * Purpose      - This function sets the two icon members of the window class
 *                by loading in the big and small icon from the icon resource
 *                ID Passed in.
 * Arguments    - resID: Resource ID number of the icon resource to use.
 * Return Value - None
 ****************************************************************************/
void CWindowClass::setResIcons (INT resId)
{
 setResIcons (MAKEINTRESOURCE (resId));
}

/*****************************************************************************
 * Name         - CWindowClass::setResIcons
 * Purpose      - This function sets the two icon members of the window class
 *                by loading in the big and small icon from the icon resource
 *                ID Passed in. This works the same as the other SetResIcons
 *                function except this one takes a string resource name and
 *                not an INT. An exception is thrown if one or both icons
 *                could not be loaded.
 * Arguments    - resName: String containing the resource name
 * Return Value - None
 ****************************************************************************/
void CWindowClass::setResIcons (CHAR *resName)
{
 hIcon = LoadIcon (hInstance , resName);
 if (hIcon == NULL)
     throw CException ("LoadIcon Failed!");

 hIconSm = (HICON) LoadImage (hInstance,
                              resName,
                              IMAGE_ICON,
                              16 ,
                              16 ,
                              0);
 if (hIconSm == NULL)
     throw CException ("LoadImage Failed!");
}

/*****************************************************************************
 * Name         - CWindowClass::register
 * Purpose      - This functions registers the window class with windows. It
 *                first tries to use RegisterClassEx to register the class.
 *                If that fails it tries the standard RegisterClass function.
 * Arguments    - None
 * Return Value - YES if the class was registered
 *                NO on failure
 ****************************************************************************/
BOOL CWindowClass::registerClass (void)
{
 if (!RegisterClassEx (this)) {
     if (!RegisterClass ((LPWNDCLASS) &(this->style)))
         return NO;
 }

 return YES;
}

/****************************************************************************/

