// This file is wholly ignored by the compiler if debugging information is
// not wanted.

#ifdef __DEBUG__

/****************************************************************************/

#include "winlib.h"

// These defines are used by the DebugMessage command to find the main WinNote
// window (if one exists).
#define WINNOTE_CLASS   "BS_TRAYDEBUGWINDOW"
#define WINNOTE_CAPTION "$$->WINNOTE DEBUG CLIENT<-$$"

// This defines the message that gets sent out via the DEBUGMSG macro.
CHAR winlibDebuggingMessage[2048];

/*****************************************************************************
 * Name         - windowAssert
 * Purpose      - This is the help function used by the WINASSERT macro. It
 *                creates a string that defines what condition failed, and its
 *                position in the code, and then throws an exception. This is
 *                only defined if debugging information is enabled.
 * Arguments    - condition: String defining the assertion that failed
 *                file: The file the assertion failed on
 *                line: The line number of the assertion failure
 * Return Value - None
 ****************************************************************************/
void windowAssert (CHAR *condition , CHAR *file , INT line)
{
 CHAR buffer[1024];

 wsprintf (buffer , "WINASSERT Failed on condition\n\n"
                      "%s\n\n"
                      "in file %s at line %d" ,
           condition , file , line);

 throw CException (buffer , 0);
}

// A simple helper function which returns only the filename portion of the string
// if there is a path.
CHAR *clipPath (CHAR *filename)
{
    // Find the last path separator
    CHAR *temp = strrchr (filename , '\\');

    // If we found it, return the pointer to the character
    // one past it. Otherwise, return what was passed in.
    if (temp)
        return temp + 1;
    else
        return filename;
}

/*****************************************************************************
 * Name         - debugMessage
 * Purpose      - This function tries to locate the WinNote program, if it
 *                is running, and ask it the window handle to the edit control
 *                used in the debug window. If it finds out that information
 *                it adds the given debug message to the end of the control.
 *                Otherwise it does nothing. The function adds a cr/lf pair
 *                to the end of the string so that it ends up on a line by
 *                itself.
 * Arguments    - format: Debug message to output in printf format
 * Return Value - None
 ****************************************************************************/
void debugMessage (CHAR *format , ...)
{
 static CHAR formattedMessage[1024];

 // Try to find the handle to the WinNote main window.
 HWND winNote = FindWindow (WINNOTE_CLASS , WINNOTE_CAPTION);

 // If we didn't find it then just return because we can't do anything.
 if (winNote == NULL)
     return;

 // First, use the information that we have to create a formatted message.
 va_list args;
 va_start (args , format);
 vsprintf (formattedMessage , format , args);
 va_end (args);

 // Now contatenate it onto the previously defined data
 strcat (winlibDebuggingMessage , formattedMessage);

 // Create a global atom for the debug string. If it didnt work we can't do
 // anything so return.
 ATOM debugMsg = GlobalAddAtom (winlibDebuggingMessage);
 if (debugMsg == 0)
     return;

 // Tell winnote to output the message. This will not return until the
 // SendMessage function returns.
 SendMessage (winNote , WM_WINLIBDEBUGMSG , 0 , (LPARAM) debugMsg);

 // Now free up the atom
 GlobalDeleteAtom (debugMsg);
}

/****************************************************************************/

#endif
