/****************************************************************************/

#include "genapp.h"

/****************************************************************************/

// This is the class which handles and dispatches messages for the main window
// in the application.
class CMainWndDispatcher : public CDispatcher {
 public:
     CMainWndDispatcher (handlerType handler) : CDispatcher (handler) {}

     LRESULT msgDestroy (HWND , UINT , WPARAM , LPARAM);

     LRESULT cmdWinAssert (HWND , WORD , WORD , HWND);
     LRESULT cmdUnknown   (HWND , WORD , WORD , HWND);
     LRESULT cmdDebugTest (HWND , WORD , WORD , HWND);
     LRESULT cmdExit      (HWND , WORD , WORD , HWND);

 MESSAGE_LIST;
 COMMAND_LIST;
};

START_MESSAGE_LIST (CMainWndDispatcher)
    MESSAGE (WM_DESTROY , msgDestroy)
END_MESSAGE_LIST

START_COMMAND_LIST (CMainWndDispatcher)
    COMMAND (IDM_WINASSERT    , cmdWinAssert)
    COMMAND (IDM_UNKNOWN      , cmdUnknown)
    COMMAND (IDM_DEBUGTEST    , cmdDebugTest)
    COMMAND (IDM_FILEEXIT     , cmdExit)
END_COMMAND_LIST

/****************************************************************************/

CMainWndDispatcher mainWindowDispatch (handlerWindow);

/*****************************************************************************
 * Name         - WndProc
 * Purpose      - This handles messages sent to the main window. It uses the
 *                windows dispatching class to do it's job.
 * Arguments    - Standard window procedure parameters
 * Return Value - Depends on the message processes
 ****************************************************************************/
LRESULT CALLBACK wndProc (HWND hWnd , UINT uMessage,
                          WPARAM wParam , LPARAM lParam)
{
    return mainWindowDispatch.dispatchMessage (hWnd, uMessage, wParam, lParam);
}

/*****************************************************************************
 * Name         - CMainWndDispatcher::MsgDestroy
 * Purpose      - This handles the WM_DESTROY message sent to the window. It
 *                posts a quit message to the main window, which causes the
 *                message loop to terminte and make the application terminate.
 * Arguments    - None Used
 * Return Value - 0
 ****************************************************************************/
LRESULT CMainWndDispatcher::msgDestroy (HWND /*hWnd*/ , UINT /*uMessage*/,
                                        WPARAM /*wParam*/ , LPARAM /*lParam*/)
{
    PostQuitMessage (0);
    return 0;
}

/*****************************************************************************
 * Name         - CMainWndDispatcher::CmdWinAssert
 * Purpose      - This function is called in response to the user choosing the
 *                file menu item relating to WINASSERT. We create a WINASSERT
 *                failure to demonstrate what they look like
 * Arguments    - None Used
 * Return Value - 0
 ****************************************************************************/
LRESULT CMainWndDispatcher::cmdWinAssert (HWND hWnd, WORD /*wCommand*/,
                                          WORD /*wNotify*/, HWND /*hwndCtrl*/)
{
#ifndef __DEBUG__
    MessageBox (hWnd , "Can't generate an assertion failure, I'm not in debug mode!" ,
                       "Can't do WINASSERT" , MB_ICONINFORMATION | MB_OK);
#endif

    // This will generate warnings. Ignore it.
    WINASSERT (TRUE == FALSE);

    return 0;
}

/*****************************************************************************
 * Name         - CMainWndDispatcher::CmdUnknown
 * Purpose      - This function is called in response to the user choosing the
 *                file menu item relating to unknown exceptions. We create a 
 *                fake exception to demonstrate what they look like
 * Arguments    - None Used
 * Return Value - 0
 ****************************************************************************/
LRESULT CMainWndDispatcher::cmdUnknown (HWND /*hWnd*/, WORD /*wCommand*/,
                                        WORD /*wNotify*/, HWND /*hwndCtrl*/)
{
    // This will generate warnings. Ignore it.
    throw 12;

    return 0;
}

/*****************************************************************************
 * Name         - CMainWndDispatcher::CmdDebugTest
 * Purpose      - This function is called in response to the user choosing the
 *                file menu item relating to debug testing. It sends a debug
 *                message to the WinNote debug window, if WinNote is running.
 * Arguments    - None Used
 * Return Value - 0
 ****************************************************************************/
LRESULT CMainWndDispatcher::cmdDebugTest (HWND hWnd, WORD /*wCommand*/,
                                          WORD /*wNotify*/, HWND /*hwndCtrl*/)
{
#ifndef __DEBUG__
    MessageBox (hWnd , "Can't generate a debug message, I'm not in debug mode!" ,
                       "Can't do DEBUGMSG" , MB_ICONINFORMATION | MB_OK);
#endif

    DEBUGMSG ("This is a sample debug message from the WinLib test application");

    return 0;
}

/*****************************************************************************
 * Name         - CMainWndDispatcher::CmdExit
 * Purpose      - This function is called in response to the user choosing the
 *                exit menu item from the file menu. It simply tells the
 *                window to close.
 * Arguments    - hWnd: Window being closed
 * Return Value - 0
 ****************************************************************************/
LRESULT CMainWndDispatcher::cmdExit (HWND hWnd, WORD /*wCommand*/,
                                     WORD /*wNotify*/, HWND /*hwndCtrl*/)
{
    PostMessage (hWnd , WM_CLOSE , 0 , 0);
    return 0;
}

/****************************************************************************/

