#ifndef __WINDEBUGdotH__
#define __WINDEBUGdotH__

// Define the window message that we will use to communicate to WinNote to
// tell our debug program to output a debug message
#define WM_WINLIBDEBUGMSG (WM_USER + 100)

#ifdef __DEBUG__

// Debugging is wanted. Prototype the function that we use to show the
// exception and then define the WINASSERT macro to call it if the given
// condition evaluates to false.
//
// Note to self. Visual C++ 6 is so retarded that the WinAssert macro will
// cause an internal compiler error if you say !(c) instead of (c) == 0.
void windowAssert (CHAR *condition , CHAR *file , INT line);
#define WINASSERT(c) if ((c) == 0) windowAssert (#c , __FILE__ , __LINE__)

// We want our debug messaging to automatically prefix the file and line that
// the debug was isssued from. We also want to have the macro work like
// printf (i.e. a variable number of parameters). Because you can't make a
// macro that takes a variable number of parameters we have to fake that.
// This global variable is used to store the debug string that is eventually
// sent out by the DebugMessage function.
extern CHAR winlibDebuggingMessage[2048];

// Define the Debugging macro and make sure that the function which is used
// to output the message gets prototyped
void debugMessage (CHAR *Format , ...);

// A simple helper function which returns only the filename portion of the string
// if there is a path.
CHAR *clipPath (CHAR *filename);

// This first makes a string of the file and line, then calls the DebugMessage
// function with whatever parameters that the macro had. This is just a dressed
// up call to DebugMessage to set things the way we want them.
#define DEBUGMSG \
    sprintf (winlibDebuggingMessage , \
             "[%s:%d] " , clipPath (__FILE__) , __LINE__); \
    debugMessage

#else

// Debugging is not wanted. Define WINASSERT and DEBUGMSG macro's that
// don't expand out to anything.
#define WINASSERT(c)
#define DEBUGMSG

#endif

#endif
