#ifndef __WINPTRdotH__
#define __WINPTRdotH__

#include <string.h>

// This class defines an automatic pointer. That is, a class that carries a
// piece of allocated memory for it's lifetime. The constructor takes a number
// that is the number of bytes that the pointer should allocate initially.
// The destructor takes care of getting rid of the allocated data when the
// object's life is over.
//
// Members are available to get mutable and non-mutable instances of the
// data directly, and also as implicit type conversion operators, so that
// the class object can be used in place of a normal pointer.
//
// Because the class is defined to be an automatic pointer, you cannot create
// a dynamic instance of it. If you try, the result is always a null pointer.
class CAutoPtr
{
 public:
     CAutoPtr (INT4 size)
     {
         if (size == 0)
            size = 64;
         sizeOfData = size;
         dataBytes = new BYTE[sizeOfData];
     }
     ~CAutoPtr ()
     {
         delete[] dataBytes;
     }

     // Explicitly access the data as bytes (const) or mutable bytes
     // pointer. Also allowed to pass in an offset. If the offset is past
     // the size of the object, a null pointer is returned instead.
     BYTE *mutableBytes (INT4 offset = 0)
     {
         if (offset > sizeOfData)
             return NULL;
         else
             return dataBytes + offset;
     }
     const BYTE *bytes (INT4 offset = 0) {return mutableBytes (offset);}

     // Returns the size of the data.
     INT4 size () {return sizeOfData;}

     // Operators. Return a char or const char pointer as needed. Also an
     // operator new that always returns a null class instance, to enforce
     // the rule that auto pointers are automatic and not dynamic.
     operator char * () {return dataBytes;}
     operator const char * () {return dataBytes;}
     void *operator new (size_t size) {return NULL;}

 private:
     // Private stuff. The pointer that holds the data and a variable that
     // holds the size of the data.
     BYTE *dataBytes;
     INT4 sizeOfData;
};

#endif
