/****************************************************************************/

#include "winlib.h"

/*****************************************************************************
 * Name         - WinMain
 * Purpose      - The program execution starts at this point. We set up any
 *                WinLib globals that need to be set up, and then call the
 *                WinLibMain function, which is where the user defines their
 *                entry point into the program. We Wrap the call to WinLibMain
 *                in a try block, as well as providing a catch block, so that
 *                the user doesn't have to worry about doing exception
 *                catching.
 * Arguments    - hInstance: Instance handle of the program
 *                lpCmdLine: Pointer to the command line of the program
 *                nCmdShow: Initial show state for the window
 * Return Value -
 ****************************************************************************/
INT APIENTRY WinMain(HINSTANCE hInstance,
                     HINSTANCE /*hPrevInstance*/,
                     LPSTR     lpCmdLine,
                     INT       nCmdShow)
{
 _set_new_handler (&winLibNewHandler);

 INT retVal = YES;

 try {
     retVal = winLibMain (hInstance , lpCmdLine , nCmdShow);
 }

 catch (CException exception) {
     // If the error code is 0, then just use whatever message that was
     // attached to the exception as an error code. Otherwise, we will
     // make up a message that also includes the error code.
     CHAR buf [1024];

     if (exception.getError () == 0)
         strcpy (buf , exception.getMessage ());
      else
         wsprintf (buf , "%s\n\nError code %d" , exception.getMessage () ,
                   exception.getError ());

     MessageBox (NULL , buf , "WinLib Exception" , MB_ICONERROR | MB_OK);

     retVal = NO;
 }

 catch (...) {
     MessageBox (NULL , "An unknown exception has been detected!\n"
                        "This is very Bad! Please report this error immediatly,\n"
                        "along with a report of what you where doing at the time\n"
                        "it occurred! Thank you" ,
                        "Unhandled Exception Error" ,
                        MB_ICONERROR | MB_OK);
     retVal = NO;
 }

 return retVal;
}

/****************************************************************************/

